==> jboss-wfk-2.0.0-errai-tech-preview-src.zip: jboss-wfk-2.0.0/src/errai-2.0.1.Final-redhat-1/errai-jaxrs/errai-jaxrs-client/src/test/java/org/jboss/errai/enterprise/jaxrs/server/QueryParamTestServiceImpl.java <==
/*
 * Copyright 2011 JBoss, by Red Hat, Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.errai.enterprise.jaxrs.server;

import org.jboss.errai.enterprise.jaxrs.client.shared.QueryParamTestService;

/**
 * Implementation of {@link QueryParamTestService} returning test data.
 * 
 * @author Christian Sadilek <csadilek@redhat.com>
 */
public class QueryParamTestServiceImpl implements QueryParamTestService {

  @Override
  public Long getWithQueryParam(long id) {
    return id;
  }

  @Override
  public String getWithStringQueryParam(String id) {
    return id;
  }
  
  @Override
  public String getWithMultipleQueryParams(long id1, long id2) {
    return "" + id1 + "/" + id2;
  } 
  
  @Override
  public int postWithQueryParam(int id) {
    return id;
  }

  @Override
  public Double putWithQueryParam(Double id) {
    return id;
  }

  @Override
  public short deleteWithQueryParam(short id) {
    return id;
  }

  @Override
  public void headWithQueryParam(long id) {
  }
}

==> jboss-wfk-2.2.0-errai-tech-preview-src.zip: jboss-wfk-2.2.0/src/errai-2.2.0.Final-redhat-1/errai-jaxrs/errai-jaxrs-client/src/test/java/org/jboss/errai/enterprise/jaxrs/server/QueryParamTestServiceImpl.java <==
/*
 * Copyright 2011 JBoss, by Red Hat, Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.errai.enterprise.jaxrs.server;

import org.jboss.errai.enterprise.jaxrs.client.shared.QueryParamTestService;

/**
 * Implementation of {@link QueryParamTestService} returning test data.
 * 
 * @author Christian Sadilek <csadilek@redhat.com>
 */
public class QueryParamTestServiceImpl implements QueryParamTestService {

  @Override
  public Long getWithQueryParam(long id) {
    return id;
  }

  @Override
  public String getWithStringQueryParam(String id) {
    return id;
  }
  
  @Override
  public String getWithMultipleQueryParams(long id1, long id2) {
    return "" + id1 + "/" + id2;
  } 
  
  @Override
  public int postWithQueryParam(String entity, int id) {
    return id;
  }

  @Override
  public Double putWithQueryParam(Double id) {
    return id;
  }

  @Override
  public short deleteWithQueryParam(short id) {
    return id;
  }

  @Override
  public void headWithQueryParam(long id) {
  }
}
